@@ -1,12 +1,12 @@
 /*
- *  $Id: defFind.c,v 1.18 2001/06/22 02:44:19 bkorb Exp $
+ *  $Id: defFind.c,v 1.20 2002/01/24 05:06:41 bkorb Exp $
  *  This module loads the definitions, calls yyparse to decipher them,
  *  and then makes a fixup pass to point all children definitions to
  *  their parent definition (except the fixed "rootEntry" entry).
  */
 
 /*
- *  AutoGen copyright 1992-1999 Bruce Korb
+ *  AutoGen copyright 1992-2002 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -35,16 +35,23 @@ struct defEntryList {
 };
 typedef struct defEntryList tDefEntryList;
 
-tSCC zInvalRef[]  = "invalid reference";
-tSCC zIllFormed[] = "Ill-formed segmented name:  ``%s''\n";
-tSCC zNoRoom[]    = "No room to canonicalize ``%s''\n";
+tSCC zNameRef[]   = "Ill formed name ``%s'' in %s line %d\n";
 
 tSC zDefinitionName[ MAXPATHLEN ];
 
 STATIC tDefEntry* findEntryByIndex( tDefEntry* pE, char* pzScan );
 
 
-    STATIC tDefEntry*
+STATIC void
+illFormedName( void )
+{
+    char* pz = asprintf( zNameRef, zDefinitionName,
+                         pCurTemplate->pzFileName, pCurMacro->lineNo );
+    AG_ABEND( pz );
+}
+
+
+STATIC tDefEntry*
 findEntryByIndex( tDefEntry* pE, char* pzScan )
 {
     int  idx;
@@ -61,9 +68,9 @@ findEntryByIndex( tDefEntry* pE, char* pzScan )
     if (*pzScan == '$') {
         while (isspace( *++pzScan )) ;
         if (*pzScan != ']')
-            return (tDefEntry*)NULL;
+            return NULL;
 
-        if (pE->pEndTwin != (tDefEntry*)NULL)
+        if (pE->pEndTwin != NULL)
             return pE->pEndTwin;
 
         return pE;
@@ -81,7 +88,7 @@ findEntryByIndex( tDefEntry* pE, char* pzScan )
          */
         while (isspace( *pz )) pz++;
         if (*pz != ']')
-            return (tDefEntry*)NULL;
+            return NULL;
     }
 
     else {
@@ -92,7 +99,7 @@ findEntryByIndex( tDefEntry* pE, char* pzScan )
         const char* pzVal;
 
         if (! isalpha( *pzScan ))
-            return (tDefEntry*)NULL;
+            return NULL;
 
         while (ISNAMECHAR( *pzScan )) pzScan++;
 
@@ -112,13 +119,13 @@ findEntryByIndex( tDefEntry* pE, char* pzScan )
          */
         while (isspace( *pzScan )) pzScan++;
         if (*pzScan != ']')
-            return (tDefEntry*)NULL;
+            return NULL;
 
         /*
          *  make sure we found a defined value
          */
-        if ((pzVal == (char*)NULL) || (*pzVal == NUL))
-            return (tDefEntry*)NULL;
+        if ((pzVal == NULL) || (*pzVal == NUL))
+            return NULL;
 
         idx = strtol( pzVal, &pzDef, 0 );
 
@@ -126,7 +133,7 @@ findEntryByIndex( tDefEntry* pE, char* pzScan )
          *  Make sure we got a legal number
          */
         if (*pzDef != NUL)
-            return (tDefEntry*)NULL;
+            return NULL;
     }
 
     /*
@@ -134,11 +141,11 @@ findEntryByIndex( tDefEntry* pE, char* pzScan )
      */
     do  {
         if (pE->index > idx)
-            return (tDefEntry*)NULL;
+            return NULL;
         if (pE->index == idx)
             break;
         pE = pE->pTwin;
-    } while (pE != (tDefEntry*)NULL);
+    } while (pE != NULL);
 
     return pE;
 }
@@ -165,12 +172,13 @@ addResult( tDefEntry* pDE, tDefEntryList* pDEL )
 }
 
 
-    STATIC size_t
-badName( const char* pzFmt, char* pzD, const char* pzS, size_t srcLen )
+STATIC size_t
+badName( char* pzD, const char* pzS, size_t srcLen )
 {
     memcpy( (void*)pzD, (void*)pzS, srcLen );
     pzD[ srcLen ] = NUL;
-    fprintf( stderr, pzFmt, pzD );
+    fprintf( pfTrace, zNameRef, pzD,
+             pCurTemplate->pzFileName, pCurMacro->lineNo );
     return srcLen + 1;
 }
 
@@ -185,7 +193,7 @@ badName( const char* pzFmt, char* pzD, const char* pzS, size_t srcLen )
  *      (always skipping white space).
  *  We start in CN_START.
  */
-    EXPORT int
+EXPORT int
 canonicalizeName( char* pzD, const char* pzS, int srcLen )
 {
     tSCC zNil[] = "";
@@ -238,7 +246,7 @@ canonicalizeName( char* pzD, const char* pzS, int srcLen )
     switch (state) {
     case CN_START_NAME:
         if (! isalpha( *pzS ))
-            return badName( zIllFormed, pzDst, pzOri, stLen );
+            return badName( pzDst, pzOri, stLen );
         state = CN_NAME_ENDED;  /* we found the start of our first name */
         break;  /* fall through to name/number consumption code */
 
@@ -261,7 +269,7 @@ canonicalizeName( char* pzD, const char* pzS, int srcLen )
         }
 
         if (--srcLen <= 0)
-            return badName( zIllFormed, pzDst, pzOri, stLen );
+            return badName( pzDst, pzOri, stLen );
         goto nextSegment;
 
     case CN_INDEX:
@@ -292,7 +300,7 @@ canonicalizeName( char* pzD, const char* pzS, int srcLen )
          */
         if (*pzS == '$') {
             if (--srcLen < 0)
-                return badName( zIllFormed, pzDst, pzOri, stLen );
+                return badName( pzDst, pzOri, stLen );
 
             *(pzD++) = *(pzS++);
             goto nextSegment;
@@ -304,7 +312,7 @@ canonicalizeName( char* pzD, const char* pzS, int srcLen )
          *  Nothing else is okay.
          */
         if ((*(pzD++) = *(pzS++)) != ']')
-            return badName( zIllFormed, pzDst, pzOri, stLen );
+            return badName( pzDst, pzOri, stLen );
 
         if (--srcLen <= 0) {
             *pzD = NUL;
@@ -371,7 +379,7 @@ canonicalizeName( char* pzD, const char* pzS, int srcLen )
  *  the element has been indexed (so the caller will not try
  *  to traverse the list of twins).
  */
-    STATIC tDefEntry*
+STATIC tDefEntry*
 defEntrySearch( char* pzName, tDefStack* pDefStack, ag_bool* pIsIndexed )
 {
     char*        pcBrace;
@@ -392,7 +400,7 @@ defEntrySearch( char* pzName, tDefStack* pDefStack, ag_bool* pIsIndexed )
         canonicalizeName( zDefinitionName, pzName, strlen( pzName ));
         pzName = zDefinitionName;
 
-        if (pIsIndexed != (ag_bool*)NULL)
+        if (pIsIndexed != NULL)
              *pIsIndexed = AG_FALSE;
         else pIsIndexed  = &dummy;
 
@@ -414,8 +422,8 @@ defEntrySearch( char* pzName, tDefStack* pDefStack, ag_bool* pIsIndexed )
          *  THEN it is time to bail out.
          */
         pE = pDefStack->pDefs;
-        if (pE == (tDefEntry*)NULL)
-            return (tDefEntry*)NULL;
+        if (pE == NULL)
+            return NULL;
 
         do  {
             /*
@@ -426,21 +434,21 @@ defEntrySearch( char* pzName, tDefStack* pDefStack, ag_bool* pIsIndexed )
                 goto found_def_entry;
 
             pE = pE->pNext;
-        } while (pE != (tDefEntry*)NULL);
+        } while (pE != NULL);
 
         /*
          *  IF we are nested, then we cannot change the definition level.
          *  So, we did not find anything.
          */
         if ((nestingDepth != 0) || noNesting)
-            return (tDefEntry*)NULL;
+            return NULL;
 
         /*
          *  Let's go try the definitions at the next higher level.
          */
         pDefStack = pDefStack->pPrev;
         if (pDefStack == NULL)
-            return (tDefEntry*)NULL;
+            return NULL;
     } found_def_entry:;
 
     /*
@@ -461,17 +469,15 @@ defEntrySearch( char* pzName, tDefStack* pDefStack, ag_bool* pIsIndexed )
         while (isspace( *++pcBrace )) ;
 
         pE = findEntryByIndex( pE, pcBrace );
-        if (pE == (tDefEntry*)NULL)
+        if (pE == NULL)
             return pE;
 
         /*
          *  We must find the closing brace, or there is an error
          */
         pcBrace = strchr( pcBrace, ']' );
-        if (pcBrace == (char*)NULL) {
-            fprintf( stderr, zIllFormed, zDefinitionName );
-            AG_ABEND;
-        }
+        if (pcBrace == NULL)
+            illFormedName();
 
         /*
          *  IF we are at the end of the definition,
@@ -485,8 +491,7 @@ defEntrySearch( char* pzName, tDefStack* pDefStack, ag_bool* pIsIndexed )
             break;
 
         default:
-            fprintf( stderr, zIllFormed, zDefinitionName );
-            AG_ABEND;
+            illFormedName();
         }
         /* FALLTHROUGH */
 
@@ -500,15 +505,14 @@ defEntrySearch( char* pzName, tDefStack* pDefStack, ag_bool* pIsIndexed )
         break;
 
     default:
-        fprintf( stderr, zIllFormed, zDefinitionName );
-        AG_ABEND;
+        illFormedName();
     }
 
     /*
      *  We cannot find a member of a non-block type macro definition.
      */
     if (pE->valType != VALTYP_BLOCK)
-        return (tDefEntry*)NULL;
+        return NULL;
 
     /*
      *  Loop through all the twins of the entry we found until
@@ -525,7 +529,7 @@ defEntrySearch( char* pzName, tDefStack* pDefStack, ag_bool* pIsIndexed )
             tDefEntry* res;
 
             res = defEntrySearch( pzName, &stack, pIsIndexed );
-            if ((res != (tDefEntry*)NULL) || (breakCh == '[')) {
+            if ((res != NULL) || (breakCh == '[')) {
                 nestingDepth--;
                 return res;
             }
@@ -537,11 +541,11 @@ defEntrySearch( char* pzName, tDefStack* pDefStack, ag_bool* pIsIndexed )
     }
 
     nestingDepth--;
-    return (tDefEntry*)NULL;
+    return NULL;
 }
 
 
-    EXPORT tDefEntry*
+EXPORT tDefEntry*
 findDefEntry( char* pzName, ag_bool* pIsIndexed )
 {
     return defEntrySearch( pzName, &currDefCtx, pIsIndexed );
@@ -557,7 +561,7 @@ findDefEntry( char* pzName, ag_bool* pIsIndexed )
  *  indicator saying if the element has been indexed (so the caller will
  *  not try to traverse the list of twins).
  */
-    STATIC tDefEntry**
+STATIC tDefEntry**
 entryListSearch( char* pzName, tDefStack* pDefStack )
 {
     static tDefEntryList defList = { 0, 0, NULL, 0 };
@@ -594,23 +598,19 @@ entryListSearch( char* pzName, tDefStack* pDefStack )
          *  THEN it is time to bail out.
          */
         pE = pDefStack->pDefs;
-        if (pE == (tDefEntry*)NULL) {
+        if (pE == NULL) {
             /*
              *  Make sure we are not nested.  Once we start to nest,
              *  then we cannot "change definition levels"
              */
         not_found:
-            if (defList.nestLevel != 0) {
-                tSCC z[] =
-                    "reached ROOT def resolving last subcomponent:  `%s'\n";
-                fprintf( stderr, z, zDefinitionName );
-                AG_ABEND;
-            }
+            if (defList.nestLevel != 0)
+                illFormedName();
 
             /*
              *  Don't bother returning zero entry list.  Just return NULL.
              */
-            return (tDefEntry**)NULL;
+            return NULL;
         }
 
         do  {
@@ -622,7 +622,7 @@ entryListSearch( char* pzName, tDefStack* pDefStack )
                 goto found_def_entry;
 
             pE = pE->pNext;
-        } while (pE != (tDefEntry*)NULL);
+        } while (pE != NULL);
 
         /*
          *  IF we are nested, then we cannot change the definition level.
@@ -661,17 +661,15 @@ entryListSearch( char* pzName, tDefStack* pDefStack )
         while (isspace( *++pcBrace )) ;
 
         pE = findEntryByIndex( pE, pcBrace );
-        if (pE == (tDefEntry*)NULL)
+        if (pE == NULL)
             goto returnResult;
 
         /*
          *  We must find the closing brace, or there is an error
          */
         pcBrace = strchr( pcBrace, ']' );
-        if (pcBrace == (char*)NULL) {
-            fprintf( stderr, zIllFormed, zDefinitionName );
-            AG_ABEND;
-        }
+        if (pcBrace == NULL)
+            illFormedName();
 
         /*
          *  IF we are at the end of the definition,
@@ -685,8 +683,7 @@ entryListSearch( char* pzName, tDefStack* pDefStack )
             break;
 
         default:
-            fprintf( stderr, zIllFormed, zDefinitionName );
-            AG_ABEND;
+            illFormedName();
         }
         /* FALLTHROUGH */
 
@@ -700,15 +697,14 @@ entryListSearch( char* pzName, tDefStack* pDefStack )
         break;
 
     default:
-        fprintf( stderr, zIllFormed, zDefinitionName );
-        AG_ABEND;
+        illFormedName();
     }
 
     /*
      *  We cannot find a member of a non-block type macro definition.
      */
     if (pE->valType != VALTYP_BLOCK)
-        return (tDefEntry**)NULL;
+        return NULL;
 
     /*
      *  Loop through all the twins of the entry.  We ignore twins if we just
@@ -740,7 +736,7 @@ entryListSearch( char* pzName, tDefStack* pDefStack )
 }
 
 
-    EXPORT tDefEntry**
+EXPORT tDefEntry**
 findEntryList( char* pzName )
 {
     return entryListSearch( pzName, &currDefCtx );
@@ -748,5 +744,6 @@ findEntryList( char* pzName )
 /*
  * Local Variables:
  * c-file-style: "stroustrup"
+ * indent-tabs-mode: nil
  * End:
  * end of defFind.c */
