@@ -2,7 +2,7 @@
 /*  -*- Mode: C -*-
  *
  *  expMake.c
- *  $Id: expMake.c,v 1.2 2002/03/27 05:15:11 bkorb Exp $
+ *  $Id: expMake.c,v 1.3 2002/04/14 22:31:42 bkorb Exp $
  *  This module implements Makefile construction functions.
  */
 
@@ -38,7 +38,7 @@
  *
  * doc:
  *  This function will take ordinary shell script text and reformat it
- *  so that it will work properly inside of a shell script.
+ *  so that it will work properly inside of a makefile shell script.
  *  Not every shell construct can be supported; the intent is to have
  *  most ordinary scripts work without much, if any, alteration.
  *
@@ -105,14 +105,20 @@ ag_scm_makefile_script( SCM text )
 
     SCM    res;
     char*  pzText = ag_scm2zchars( text, "GPL line prefix" );
-    char   tabch  = (*pzText == '\t') ? NUL : '\t';
+    char   tabch;
     size_t sz     = strlen( pzText ) + 2;
 
     /*
      *  skip all blank lines and other initial white space
      *  in the source string.
      */
-    while (isspace( *pzText ))  pzText++;
+    if (! isspace( *pzText ))
+        tabch = '\t';
+    else {
+        while (isspace( *++pzText ))  ;
+        tabch  = (pzText[-1] == '\t') ? NUL : '\t';
+    }
+
     if (*pzText == NUL)
         return gh_str02scm( "" );
 
